==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/PercentChangeYAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericYAxisDescriptionMetadata } from "./NumericYAxisDescriptionMetadata";
import { PercentChangeYAxisDescription } from "./PercentChangeYAxisDescription";
/**
 * @hidden
 */
export let PercentChangeYAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentChangeYAxisDescriptionMetadata extends Base {
        static b(a) {
            if (PercentChangeYAxisDescriptionMetadata.a == null) {
                PercentChangeYAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentChangeYAxisDescriptionMetadata.c(PercentChangeYAxisDescriptionMetadata.a);
            }
            if (a.j(PercentChangeYAxisDescriptionMetadata.a)) {
                return;
            }
            a.y(PercentChangeYAxisDescriptionMetadata.a);
        }
        static c(a) {
            NumericYAxisDescriptionMetadata.c(a);
        }
        static d(a) {
            PercentChangeYAxisDescriptionMetadata.b(a);
            a.aa("PercentChangeYAxis", () => new PercentChangeYAxisDescription());
            a.z("PercentChangeYAxis", PercentChangeYAxisDescriptionMetadata.a);
        }
    }
    PercentChangeYAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentChangeYAxisDescriptionMetadata, 'PercentChangeYAxisDescriptionMetadata');
    PercentChangeYAxisDescriptionMetadata.a = null;
    return PercentChangeYAxisDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/PercentChangeYAxisDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { NumericYAxisDescriptionMetadata } from "./NumericYAxisDescriptionMetadata";
import { PercentChangeYAxisDescription } from "./PercentChangeYAxisDescription";
/**
 * @hidden
 */
export let PercentChangeYAxisDescriptionMetadata = /*@__PURE__*/ (() => {
    class PercentChangeYAxisDescriptionMetadata extends Base {
        static b(a) {
            if (PercentChangeYAxisDescriptionMetadata.a == null) {
                PercentChangeYAxisDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                PercentChangeYAxisDescriptionMetadata.c(PercentChangeYAxisDescriptionMetadata.a);
            }
            if (a.k(PercentChangeYAxisDescriptionMetadata.a)) {
                return;
            }
            a.aa(PercentChangeYAxisDescriptionMetadata.a);
        }
        static c(a) {
            NumericYAxisDescriptionMetadata.c(a);
        }
        static d(a) {
            PercentChangeYAxisDescriptionMetadata.b(a);
            a.ac("PercentChangeYAxis", () => new PercentChangeYAxisDescription());
            a.ab("PercentChangeYAxis", PercentChangeYAxisDescriptionMetadata.a);
        }
    }
    PercentChangeYAxisDescriptionMetadata.$t = /*@__PURE__*/ markType(PercentChangeYAxisDescriptionMetadata, 'PercentChangeYAxisDescriptionMetadata');
    PercentChangeYAxisDescriptionMetadata.a = null;
    return PercentChangeYAxisDescriptionMetadata;
})();
